EXPORTS
	??1CFsSendAsHelper@@UAE@XZ @ 1 NONAME ; CFsSendAsHelper::~CFsSendAsHelper(void)
	?AddAttachmentL@CFsSendAsHelper@@QAEXABVTDesC16@@ABVTDesC8@@I@Z @ 2 NONAME ; void CFsSendAsHelper::AddAttachmentL(class TDesC16 const &, class TDesC8 const &, unsigned int)
	?AddRecipientL@CFsSendAsHelper@@QAEXABVTDesC16@@0K@Z @ 3 NONAME ; void CFsSendAsHelper::AddRecipientL(class TDesC16 const &, class TDesC16 const &, unsigned long)
	?LaunchUiL@CFsSendAsHelper@@QAEXIIHH@Z @ 4 NONAME ; void CFsSendAsHelper::LaunchUiL(unsigned int, unsigned int, int, int)
	?NewL@CFsSendAsHelper@@SAPAV1@XZ @ 5 NONAME ; class CFsSendAsHelper * CFsSendAsHelper::NewL(void)
	?SetBodyL@CFsSendAsHelper@@QAEXABVTDesC16@@@Z @ 6 NONAME ; void CFsSendAsHelper::SetBodyL(class TDesC16 const &)
	?SetSubjectL@CFsSendAsHelper@@QAEXABVTDesC16@@@Z @ 7 NONAME ; void CFsSendAsHelper::SetSubjectL(class TDesC16 const &)
	?StoreDataL@CFsSendAsHelper@@QAEXII@Z @ 8 NONAME ; void CFsSendAsHelper::StoreDataL(unsigned int, unsigned int)
	?AddAttachmentL@CFsSendAsHelper@@QAEXAAVRFile@@ABVTDesC8@@I@Z @ 9 NONAME ; void CFsSendAsHelper::AddAttachmentL(class RFile &, class TDesC8 const &, unsigned int)

